/* c-irrlicht --- C bindings for Irrlicht Engine

   Copyright (C) 2019 Javier Sancho <jsf@jsancho.org>

   This file is part of c-irrlicht.

   c-irrlicht is free software; you can redistribute it and/or modify
   it under the terms of the GNU Lesser General Public License as
   published by the Free Software Foundation; either version 3 of the
   License, or (at your option) any later version.

   c-irrlicht is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with guile-irrlicht.  If not, see
   <http://www.gnu.org/licenses/>.
*/

#include <irrlicht/irrlicht.h>
#include "IVideoDriver.h"

extern "C" {
  int
  irr_video_beginScene(irr_video_IVideoDriver* driver,
                       int backBuffer,
                       int zBuffer,
                       const irr_video_SColor* color,
                       irr_video_SExposedVideoData* videoData,
                       const irr_core_rect_s32* sourceRect)
  {
    // Color
    irr::video::SColor col = irr::video::SColor(color->a, color->r,
                                                color->g, color->b);

    // Video data
    // TODO
    irr::video::SExposedVideoData vdata = irr::video::SExposedVideoData();

    // Source rect
    irr::core::rect<irr::s32> rect;
    if (sourceRect != NULL)
      {
        rect = irr::core::rect<irr::s32>(sourceRect->x,
                                         sourceRect->y,
                                         sourceRect->x2,
                                         sourceRect->y2);
      }

    // Begin scene
    return ((irr::video::IVideoDriver*)driver)
      ->beginScene(backBuffer,
                   zBuffer,
                   col,
                   vdata,
                   sourceRect != NULL ? &rect : 0);
  }

  int
  irr_video_endScene(irr_video_IVideoDriver* driver)
  {
    return ((irr::video::IVideoDriver*)driver)->endScene();
  }

  irr_video_ITexture*
  irr_video_getTexture(irr_video_IVideoDriver* driver,
                       const char* filename)
  {
    return (irr_video_ITexture*)
      ((irr::video::IVideoDriver*)driver)->getTexture(filename);
  }

}
